from django import template
from webcolor import *
register = template.Library()

@register.filter
def lightness(value, arg):
    value = value.copy()
    arg = arg.strip()
    if arg.endswith('%'):
        arg = float(arg[:-1]) / 100.0
        value.l *= arg
    else:
        arg = float(arg)
        value.l = arg
    return value

@register.filter
def saturation(value, arg):
    value = value.copy()
    arg = arg.strip()
    if arg.endswith('%'):
        arg = float(arg[:-1]) / 100.0
        value.s *= arg
    else:
        arg = float(arg)
        value.s = arg
    return value


@register.simple_tag
def HSL(h, s, l):
    try:
        h = float(h)
        s = float(s)
        l = float(l)
    except ValueError:
        raise ValueError("HSL requires a color in <H>,<L>,<S> format")
    c = WebColor.from_HSL(h, s, l)
    return str(c)

@register.simple_tag
def colorblend(col1, col2, interpolant):

    col1 = WebColor(col1)
    col2 = WebColor(col2)
    i = float(interpolant)
    col = col1.blend(col2, i)
    return str(col)
